@@ -13,3 +13,5 @@ class Miscellaneous(BrowserView):
         url = aq_parent(context).absolute_url()
         self.request.response.redirect(url)
 
+    def verkkomaksut_notify(self):
+        pass
