@@ -1,9 +1,9 @@
-from Acquisition import aq_inner, aq_parent
+from Acquisition import aq_inner#, aq_parent
 from Products.Five.browser import BrowserView
 from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
 from Products.CMFCore.utils import getToolByName
-from Products.statusmessages.interfaces import IStatusMessage
-from Products.PFGVerkkomaksut import PFGVerkkomaksutMessageFactory as _
+#from Products.statusmessages.interfaces import IStatusMessage
+#from Products.PFGVerkkomaksut import PFGVerkkomaksutMessageFactory as _
 
 class PFGVerkkomaksutSuccessView(BrowserView):
 
@@ -24,8 +24,3 @@ class PFGVerkkomaksutSuccessView(BrowserView):
                     reference_catalog = getToolByName(context, 'reference_catalog')
                     adapter = reference_catalog.lookupObject(uid)
                     return adapter.getThanksPrologue()
-
-#    def message(self):
-#        if self.has_session():
-#            uid = self.request.SESSION.pfg.verkkomaksut/ADAPTER_UID
-#            adapter python: context.reference_catalog.lookupObject(uid)
