@@ -53,7 +53,14 @@ if HAS_PLONE30:
                 required = False,
             )
             sf = form.selection_field
-    #        sf_uid = sf.UID()
+            form.invokeFactory(
+                'FormMultiSelectionField',
+                'multi_selection_field',
+                title = 'Multi Selection',
+                required = False,
+                fgVocabulary = 'aaa|AAA\nbbb|BBB\nccc|CCC',
+            )
+            sf = form.selection_field
             form.invokeFactory(
                 'PFGVerkkomaksut',
                 'adapter',
